==> blanco.plugin.svnconf_0.0.8-src.zip: src/blanco/svnconf/resourcebundle/BlancoSvnConfResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.svnconf.resourcebundle;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoSvnConf]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 * m̃P[<BR>
 * <UL>
 * <LI>ja
 * </UL>
 */
public class BlancoSvnConfResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoSvnConfResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoSvnConf]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoSvnConfResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoSvnConf");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoSvnConfResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoSvnConf]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoSvnConfResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoSvnConf", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoSvnConfResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoSvnConf]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoSvnConfResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoSvnConf", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }

    /**
     * bundle[BlancoSvnConf], key[METAFILE_DISPLAYNAME]
     *
     * [Subversion|Wg`] (ja)<br>
     *
     * @return key[METAFILE_DISPLAYNAME]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMetafileDisplayname() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "Subversion|Wg`";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("METAFILE_DISPLAYNAME");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }
}

==> blanco.plugin.svnconf_0.1.1-src.zip: src/blanco/svnconf/resourcebundle/BlancoSvnConfResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.svnconf.resourcebundle;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoSvnConf]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 * m̃P[<BR>
 * <UL>
 * <LI>ja
 * </UL>
 */
public class BlancoSvnConfResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoSvnConfResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoSvnConf]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoSvnConfResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/svnconf/resourcebundle/BlancoSvnConf");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoSvnConfResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoSvnConf]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoSvnConfResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/svnconf/resourcebundle/BlancoSvnConf", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoSvnConfResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoSvnConf]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoSvnConfResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/svnconf/resourcebundle/BlancoSvnConf", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }

    /**
     * bundle[BlancoSvnConf], key[METAFILE_DISPLAYNAME]
     *
     * [Subversion|Wg`] (ja)<br>
     *
     * @return key[METAFILE_DISPLAYNAME]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMetafileDisplayname() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "Subversion|Wg`";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("METAFILE_DISPLAYNAME");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }
}
